==> esbuild-style-loader-0.3.0.tgz: package/esm/transform-less.js <==
function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) {
    try {
        var info = gen[key](arg);
        var value = info.value;
    } catch (error) {
        reject(error);
        return;
    }
    if (info.done) {
        resolve(value);
    } else {
        Promise.resolve(value).then(_next, _throw);
    }
}
function _async_to_generator(fn) {
    return function() {
        var self = this, args = arguments;
        return new Promise(function(resolve, reject) {
            var gen = fn.apply(self, args);
            function _next(value) {
                asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value);
            }
            function _throw(err) {
                asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err);
            }
            _next(undefined);
        });
    };
}
import lessEngine from 'less';
import { LessPluginModuleResolver } from 'less-plugin-module-resolver';
import { readFile } from 'fs/promises';
export const transformLess = function() {
    var _ref = _async_to_generator(function*(filePath, options) {
        const code = yield readFile(filePath, 'utf-8');
        const result = yield lessEngine.render(code, {
            filename: filePath,
            syncImport: true,
            /**
     * Legacy compatible
     */ plugins: [
                new LessPluginModuleResolver({
                    alias: Object.assign({
                        '~': ''
                    }, options.alias)
                })
            ],
            sourceMap: options.sourcemap ? {
                sourceMapFileInline: false,
                outputSourceFiles: true
            } : undefined
        });
        let { css, map, imports } = result;
        imports = imports.filter((item)=>item !== filePath);
        return {
            css,
            map,
            imports
        };
    });
    return function transformLess(filePath, options) {
        return _ref.apply(this, arguments);
    };
}();

==> esbuild-style-loader-0.3.1.tgz: package/esm/transform-less.js <==
function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) {
    try {
        var info = gen[key](arg);
        var value = info.value;
    } catch (error) {
        reject(error);
        return;
    }
    if (info.done) {
        resolve(value);
    } else {
        Promise.resolve(value).then(_next, _throw);
    }
}
function _async_to_generator(fn) {
    return function() {
        var self = this, args = arguments;
        return new Promise(function(resolve, reject) {
            var gen = fn.apply(self, args);
            function _next(value) {
                asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value);
            }
            function _throw(err) {
                asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err);
            }
            _next(undefined);
        });
    };
}
import { readFile } from 'node:fs/promises';
import lessEngine from 'less';
import { LessPluginModuleResolver } from 'less-plugin-module-resolver';
export const transformLess = function() {
    var _ref = _async_to_generator(function*(filePath, options) {
        const code = yield readFile(filePath, 'utf-8');
        const result = yield lessEngine.render(code, {
            filename: filePath,
            syncImport: true,
            /**
     * Legacy compatible
     */ plugins: [
                new LessPluginModuleResolver({
                    alias: Object.assign({
                        '~': ''
                    }, options.alias)
                })
            ],
            sourceMap: options.sourcemap ? {
                sourceMapFileInline: false,
                outputSourceFiles: true
            } : undefined
        });
        let { css, map, imports } = result;
        imports = imports.filter((item)=>item !== filePath);
        return {
            css,
            map,
            imports
        };
    });
    return function transformLess(filePath, options) {
        return _ref.apply(this, arguments);
    };
}();
